"""
Your package name and brief description.

Example:
    from maphub import MapHubClient

    client = MapHubClient(api_key="your-api-key")
    response = client.get_map(map_id="...")
"""

# Import the main client class and any important submodules
from .client import MapHubClient
from importlib import metadata


__version__ = metadata.version(__package__ or __name__)
__author__ = "MapHub"
__license__ = "MIT"

# Define what should be available when using "from package import *"
__all__ = ["MapHubClient"]


# Optional: You can provide a convenience function or default client instance
def create_client(api_key: str, **kwargs) -> MapHubClient:
    """
    Create an instance of the API client.

    Args:
        api_key: The API key for authentication
        **kwargs: Additional configuration options

    Returns:
        An initialized APIClient instance
    """
    return MapHubClient(api_key=api_key, **kwargs)



import uuid
from typing import Dict, Any
import requests


class MapHubClient:
    def __init__(self, api_key: str | None, base_url: str = "https://api-main-432878571563.europe-west4.run.app"):
        self.api_key = api_key
        self.base_url = base_url
        self.session = requests.Session()

        if self.api_key:
            self.session.headers.update({
                "X-API-Key": f"{self.api_key}"
            })

    def _make_request(self, method: str, endpoint: str, **kwargs) -> Dict[str, Any]:
        response = self.session.request(
            method,
            f"{self.base_url}/{endpoint.lstrip('/')}",
            **kwargs
        )
        try:
            response.raise_for_status()
        except:
            raise Exception(f"Status code {response.status_code}: {response.text}")

        return response.json()

    def get_map(self, map_id: uuid.UUID) -> Dict[str, Any]:
        return self._make_request("GET", f"/maps/{map_id}")

    def upload_map(self, map_name: str, project_id: uuid.UUID, public: bool, path: str):
        params = {
            "project_id": str(project_id),
            "map_name": map_name,
            "public": public,
            # "colormap": "viridis",
            # "vector_lod": 8,
        }

        with open(path, "rb") as f:
            return self._make_request("POST", f"/maps", params=params, files={"file": f})
